import React, { ChangeEvent, FunctionComponent, ReactElement, useEffect, useState } from "react";
import { useDispatch } from "react-redux";
import { useParams } from "react-router-dom";
import { getPostById } from "../../store/posts/posts.slice";
import { useSelector } from "react-redux";
import { RootState } from "../../store/store";
import { createComment, getCommentsByPost } from "../../store/comments/comments.slice";
import Comment from "../../components/Comment/Comment";
import Post from "../../components/Post/Post";
import ICommentDto from "../../interfaces/ICommentDto";
import './DetailsPost.css'

const DetailsPost: FunctionComponent = (): ReactElement =>  {
    const params: any = useParams();
    const dispatch = useDispatch();
    const {comments} = useSelector((state: RootState) => state.comments)
    const {post} = useSelector((state: RootState) => state.posts)
    const {user} = useSelector((state: RootState) => state.user)
    const [comment, setComment] = useState<ICommentDto>({
        user: user._id,
        post: params.id,
        comment: ''
    })
    useEffect(() => {
        //@ts-ignore
        dispatch(getPostById(params.id))
    }, [params.id])

    useEffect(() => {
        //@ts-ignore
        dispatch(getCommentsByPost(params.id))
    }, [params.id])

    const inputHandler = (e: ChangeEvent<HTMLInputElement>): void => {
        setComment(prevState => {
            return { ...prevState, [e.target.name]: e.target.value }
        })
    }

    const sendComment = () => {
        try {
            //@ts-ignore
            dispatch(createComment(comment))
        } finally {
            //@ts-ignore
            dispatch(getCommentByNews(params.id))
        }
    }

    return (
        <div className="details">
            <div className="container">
                <Post post={post} />
                {comments ? <h1>Comments</h1> : ''}
                {comments.map(c => {
                    return <Comment
                        key={c._id}
                        params_id={params.id}
                        comments={c}
                        />
                })}
                <h2>Add comment</h2>
                <div className="addcomment_block">
                    <div className="addComment">
                        <span className="addComment_title">Comment</span>
                        <input
                            value={comment.comment}
                            onChange={inputHandler}
                            name="comment"
                            type="text" />
                    </div>

                    <button className="addcomment_btn" onClick={sendComment}>Send</button>
                </div>
            </div>
        </div>
    )
}

export default DetailsPost